﻿import '@syncfusion/ej2-base/styles/material.css';
import '@syncfusion/ej2-buttons/styles/material.css';
import '@syncfusion/ej2-calendars/styles/material.css';
import '@syncfusion/ej2-dropdowns/styles/material.css';
import '@syncfusion/ej2-inputs/styles/material.css';
import '@syncfusion/ej2-navigations/styles/material.css';
import '@syncfusion/ej2-popups/styles/material.css';
import '@syncfusion/ej2-splitbuttons/styles/material.css';
import "@syncfusion/ej2-react-grids/styles/material.css";

import React from 'react';
import { DataManager, ODataV4Adaptor, Query } from '@syncfusion/ej2-data';
import { GridComponent, Filter, Sort, ColumnsDirective, ColumnDirective, DetailRow, Inject, Page } from '@syncfusion/ej2-react-grids';
import { DialogComponent } from "@syncfusion/ej2-react-popups";
import { ButtonComponent } from '@syncfusion/ej2-react-buttons';
import { TextBoxComponent, FormValidator } from '@syncfusion/ej2-react-inputs';
import { DropDownListComponent } from '@syncfusion/ej2-react-dropdowns';
import { getHeader } from '../../components/auth/localStorage'


const axios = require('axios');


export default class AssemblyAttachSequenceDialog extends React.Component {
    constructor(props) {
        super(props);

        this.header = getHeader();

        axios.defaults.headers.authorization = this.header.Authorization;
        axios.defaults.headers.crossDomain = true;

        this.state = {
            isVisible: true,
            audit: {
                AssemblyId: props.AssemblyId,
                Priority: 0,
                LineId: this.props.LineId,
            },
        }

        const API_ROOT = window.app && window.app.env.API_URL;

        this.attachUrl = API_ROOT + "/assemblies/" + props.AssemblyId + "/attach";

        this.SequenceAPI = API_ROOT + "/sequences"
        this.SequenceData = new DataManager({ url: this.SequenceAPI, adaptor: new ODataV4Adaptor(), headers: [this.header] });

        this.LineAPI = API_ROOT + "/lines"
        this.LineQuery = new Query().select(['LineId', 'ResourcesItalianText']);
        this.LineData = new DataManager({ url: this.LineAPI, adaptor: new ODataV4Adaptor(), headers: [this.header], });

        this.PhaseAPI = API_ROOT + "/phases"
        this.PhaseQuery = new Query().where('LineId', 'equal', this.props.LineId)
            .select(['PhaseId', 'ResourcesItalianText', 'LineId']);
        this.PhaseData = new DataManager({ url: this.PhaseAPI, adaptor: new ODataV4Adaptor(), headers: [this.header], });


        this.ApplicationAPI = API_ROOT + "/applications"
        this.ApplicationQuery = new Query().select(['ApplicationId', 'ApplicationName']);
        this.ApplicationData = new DataManager({ url: this.ApplicationAPI, adaptor: new ODataV4Adaptor(), headers: [this.header], });
        
        this.ToleranceMeasureAPI = API_ROOT + "/tolerancemeasures"
        this.ToleranceMeasureData = new DataManager({ url: this.ToleranceMeasureAPI, adaptor: new ODataV4Adaptor(), headers: [this.header] });

        this.MeasureChildGrid = {
            dataSource: this.ToleranceMeasureData,
            queryString: 'SequenceSequenceId',
            allowPaging: true,

            columns: [
                { field: 'MeasureMeasureId', visible: false, isPrimaryKey: true },
                { field: 'SequenceSequenceId', visible: false, isPrimaryKey: true },
                { field: 'ToleranceToleranceId', visible: false, isPrimaryKey: true },
                { field: 'MeasureMeasureOrder', visible: false, headerText: 'Measure Order' },
                { field: 'MeasureResourcesItalianText', headerText: 'Description' },
                { field: 'MeasureUnitSymbol', headerText: 'Unit', width: 100 },
                { field: 'ToleranceLow', headerText: 'Low', width: 100 },
                { field: 'ToleranceNominal', headerText: 'Nominal', width: 100 },
                { field: 'ToleranceHigh', headerText: 'High', width: 100 },
            ],

            load() {
                var str = 'SequenceId';
                this.parentDetails.parentKeyFieldValue = this.parentDetails.parentRowData[str];
            },
        };
    }

    componentDidMount = () => {
        this.formValidator = new FormValidator(".formDialog",
        {
            rules: {
                'AuditSequenceSequenceId': { required: true },
                'AuditLaps': { required: true, number: true },
                'LineId': { required: true },
                'PhaseId': { required: true },
                'AuditApplicationId': { required: true },
            },
        });
    }

    componentDidUpdate = () => {
        this.formValidator.validate();
    }

    close = () => {
        this.setState({ isVisible: false });
    }

    resetState = () => {
        let temp =
        {
            AssemblyId: this.props.AssemblyId,
            Priority: 0,
            LineId: this.props.LineId,
        };
        this.setState({ audit: temp });
    }

    submitForm = () =>
    {
        if (this.formValidator.validate()) {
            axios.post(this.attachUrl, this.state.audit)
                .then(() => {
                    alert("Sequenza associata con successo!");
                    this.close();
                    this.props.afterClosing();
                })
                .catch(error => alert('Error:', error));
        }
    }

    footerTemplate = () => {
        return (
            <div className="form-row">
                <div className="form-group col-xs-12">
                    <ButtonComponent type="submit" cssClass='e-round' iconCss='e-icons e-save-icon' isPrimary={true} onClick={this.submitForm} />
                    <ButtonComponent type="reset" cssClass='e-round' iconCss='e-icons e-reset-icon' isPrimary={true} onClick={this.resetState} />
                </div>
            </div>
        );
    }

    onSelectRow = (e) => {
        let aud = this.state.audit;
        aud.AuditSequenceSequenceId = e.data.SequenceId
        this.setState({ audit: aud });
        this.formValidator.validate('AuditSequenceSequenceId');
    }

    handleComboChange = (args) => {
        if (args.isInteracted) {
            let aud = this.state.audit;

            let key = args.element.id;
            let value = args.value;

            aud[key] = value;
            this.setState({ audit: aud });
        }
    }

    handleChange = (args) => {
        let aud = this.state.audit;

        let key = args.event.target.id;
        let value = args.value;

        aud[key] = value;
        this.setState({ audit: aud });
    }

    render() {
        return (
            <DialogComponent
                width='1200px'
                showCloseIcon={true}
                visible={this.state.isVisible}
                isModal={true}
                close={this.close}
                header={"Attaching Sequence to Assembly " + this.props.AssemblyId}
                footerTemplate={this.footerTemplate}
                allowDragging={true}
            >
                <form className="dialogContent formDialog">
                    <div className="form-row">
                        <div className="form-group col-xs-8">
                            <GridComponent
                                allowSorting={true}
                                allowFiltering={true}
                                ref={g => this.grid = g}
                                width="100%"
                                childGrid={this.MeasureChildGrid}
                                dataSource={this.SequenceData}
                                allowPaging={true}
                                rowSelecting={this.onSelectRow}
                            >

                                <ColumnsDirective>
                                    <ColumnDirective field='SequenceId' headerText="Sequence ID" isPrimaryKey={true}></ColumnDirective>
                                    <ColumnDirective field='ResourcesItalianText' width={350} headerText="Description" ></ColumnDirective>
                                </ColumnsDirective>

                                <Inject services={[DetailRow, Sort, Filter, Page]} />
                            </GridComponent>
                        </div>
                        <div className="col-xs-4">
                            <div className="form-group">
                                <div className="e-float-input e-control-wrapper">
                                    <TextBoxComponent id="AuditSequenceSequenceId" name="AuditSequenceSequenceId" enabled={false} value={this.state.audit.AuditSequenceSequenceId} placeholder="Sequence Id" floatLabelType="Auto" />
                                </div>
                            </div>
                            <div className="form-group">
                                <div className="e-float-input e-control-wrapper">
                                    <TextBoxComponent id="AuditLaps" name="AuditLaps" value={this.state.audit.AuditLaps} input={this.handleChange} placeholder="Laps" floatLabelType="Auto" />
                                </div>
                            </div>
                            <div className="form-group">
                                <div className="e-float-input e-control-wrapper">
                                    <DropDownListComponent value={this.props.LineId} id="LineId" name="LineId" enabled={false} dataSource={this.LineData} query={this.LineQuery}  fields={{ value: 'LineId', text: 'ResourcesItalianText' }} placeholder="Line" floatLabelType="Always" />
                                </div>
                            </div>
                            <div className="form-group">
                                <div className="e-float-input e-control-wrapper">
                                    <DropDownListComponent value={this.state.audit.PhaseId} id="PhaseId" name="PhaseId" dataSource={this.PhaseData}  query={this.PhaseQuery} fields={{ value: 'PhaseId', text: 'ResourcesItalianText' }} placeholder="Phase" floatLabelType="Always" change={(e) => this.handleComboChange(e)} />
                                </div>
                            </div>
                            <div className="form-group">
                                <div className="e-float-input e-control-wrapper">
                                    <DropDownListComponent value={this.state.audit.AuditApplicationId} id="AuditApplicationId" name="AuditApplicationId" dataSource={this.ApplicationData} query={this.ApplicationQuery}  fields={{ value: 'ApplicationId', text: 'ApplicationName' }} placeholder="Application" floatLabelType="Always" change={(e) => this.handleComboChange(e)} />
                                </div>
                            </div>
                        </div>
                    </div>
                </form>
            </DialogComponent>
        );
    }
}